-- Version  : $Id: sesam_db_pg.sql,v 1.42 2007/03/03 08:09:20 sesam Exp $
--
-- Title    : Database for SEP sesam2000
-- File     : sesam_db.sql
-- Author   : P.Schlegel / E.Einwanger  SEP Elektronik D83629 Weyarn
-- Date     : 4.2.1999 11:36
-- 
-- History  : Derived from Version for SESAMG (VMS GUI Version 5.04)
--
-- ============================================================================

-- ----------------------------------------------------------------------------
-- 17.01.2001 task char[15] => task char[32]
-- 17.01.2001 saveset[20] => saveset char[32]
-- 13.02.2001 loader_contents.int_drive nach media.init_drive verschoben
-- 14.02.2001 restore_results.num und restore_tasks.num entfernt
-- 24.04.2001 - Spalte media_pool VARCHAR(16) in Tabelle results eingebaut
--            - Spalte backup_cmd VARCHAR(20) in Tabelle results eingebaut
--            - Siehe Thema Nr.: 00092
--            - Vier neue Spalten in Tabelle params_fix eingebaut (typ,version,inst_date,update_date)
--            - clients_premit => clients_permit umbenannt
-- 27.04.2001 Tabelle sessions erstellt
-- 04.05.2001 - clients_permit => permit umbenannt
-- 08.05.2001 - Primary Key task_types.backup_type um NOT NULL erweitert
-- 21.05.2001 - tasks.options entfernt; task_types.source_prefix ergnzt
-- 22.05.2001 - hw_drives.timeout und restore_tasks.r_prepost ergnzt
-- 23.05.2001 - servers.rmi_port ergnzt
-- 05.07.2001 - restore_tasks um Column eol erweitert
-- 17.12.2001 - in defaults auch user_name als PRIM KEY
-- 17.12.2001 - schedules *i offset integer -> Thema 00011
-- 20.12.2001 - wegen POSTGRES: schedules.offset -> schedules.day_offset
-- 15.01.2002 - mediapools_events.drive darf auch NULL sein
-- 24.01.2002 - PSL: *i results.backup_type,restore_options
-- 25.01.2002 - PSL: *i restore_tasks.options
-- 30.01.2002 - EE:  *i cal_sheets.priority
-- 30.01.2002 - PSL: *i params_fix.inst_cryp fr Lizenzierung
-- 15.02.2002 - PSL: *i hw_drives.loader_drv,slu_id,path,block_siz,sms_nr
-- 20.02.2002 - PSL: *d hw_drives.slu_id
--                   *i hw_loaders.bar_code
--                   *m hw_loaders.typ char(20) --> char(32)
-- 21.02.2002 - EE: Umbenamsung hw_drives.loader_drv -> loader_drive
--                                       .block_siz  -> block_size
--                              hw_loaders.bar_code  -> barcode
-- 21.02.2002 - PSL: *i clients.access_options,.stpd_options,.stpd_port
--                   *d clients.text,.slave_flg
--                    -> Thema 00024 Firewall
-- 26.02.2002 - EE: *i drive_groups.restore_drive to keep default drive_num for
-- 12.03.2002 - EE: *d hw_drives.scsi_id deleted
-- 18.03.2002 - EE: *d hw_drives.intern_dn deleted  (== loader_drive)
-- 11.04.2002 - EE: *m interfaces.i_name UNIQUE bcs. referenced in task_events
-- 02.05.2002 - EE: *i restore_tasks/_results.reloc_source VARCHAR(255)
--                  *m restore_tasks/_results.target VARCHAR(255)
--                  *m restore_tasks/_results.filter VARCHAR(255)
--                  *i restore_results.options VARCHAR(64)
-- 08.05.2002 - EE: *i new table accounts 
-- 06.06.2002 - EE: *i task/newday/mediapools/command/restore_events.suppress
--                  *i accounts.service_location CHAR(64) ("local"/"server"/...)
-- 11.06.2002 - EE: *i tasks/results.compress_flag and tasks/results.crypt_key
-- 13.06.2002 - EE: *i cal_sheets.suppress
-- 17.06.2002 - EE: *i restore_tasks/restore_results.subtask_flag VARCHAR(1)
--                  *i restore_tasks/restore_results.parent_task VARCHAR(49)
-- 26.06.2002 - EE: *i tasks/results.crypt_flag VARCHAR(1)
-- 27.06.2002 - EE: *m tasks/results.crypt_key VARCHAR(128)
-- 11.07.2002 - EE: *i clients.sbc_version CHAR(20)
-- 15.07.2002 - RS: *i drive_types.generic_typ CHAR(10)
-- 31.07.2002 - PSL *i params_fix.val1 - .val4 char(128)
-- 09.08.2002 - EE: *i new table drive_vendors
-- 21.10.2002 - PSL *i table user_scheds
--                  *i schedules.usr_list  CHAR(32) references user_scheds name,
-- 24.10.2002 - EE: *m params_fix.version CHAR(32)
-- 08.11.2002 - EE: *i task_group_relations.task_order INTEGER
-- 11.11.2002 - EE: *i params_fix.msg char(128) und .sts char(128)
-- 11.11.2002 - EE: *i new table task_sources
--                  *i results.version_id INT references task_sources version_id
-- 11.02.2003 - RS  *i restore_tasks.restore_cmd and .backup_cmd
-- 13.03.2003 - MH  *i user_scheds.date_name PRIM KEY
--                  *m            .date_pattern nicht mehr PRIM KEY
-- 28.04.2003 - EE: *m user_scheds.name CHAR(30) ... references schedules.name,
--                  *d schedules.usr_list
--                  *m drive_types.drive_typ    CHAR(15) 
--                  *m hw_drives.typ            CHAR(15)
--                  *m capacities.drive_typ     CHAR(15)
--                  *m drive_vendors.drive_typ  CHAR(15)
-- 04.08.2003 - EE: *m task_sources PRIMARY KEY (task,version_id) and order of
--                    drop and create statements to fulfill reference integrity
-- 04.08.2003 - EE: *i hw_drives.name VARCHAR(32)
--                  *m tasks.source VARCHAR(254)
-- 07.09.2004 - RS: *m task_types.platform       CHAR(20) and .flags CHAR(32)
-- 10.10.2004 - RS: *m defaults.user_name        CHAR(32)
-- 07.12.2004 - RS: *m media_pools.media_strg    CHAR(64) NOT NULL
-- 12.05.2005 - EE: *m command_events.host       CHAR(64) NOT NULL
--                  *m cal_sheets.object         CHAR(132)
--                  *m restore_results.user_name CHAR(32)
--                  *m task_sources.user_name    CHAR(32)
--                  *m restore_tasks.user_name   CHAR(32)
--                  *m command_events.user_name  CHAR(32)
--                  *m clients.access_options    CHAR(256)
-- 12.05.2005 - RS: *i clients.password          CHAR(64)
--                  *m media_pools.accept_eol    CHAR(2)
--                  *m media_pools.accept_spare  CHAR(2)
--                  *m media_pools.accept_empty  CHAR(2)
-- 24.05.2005 - RS: *m clients.password          CHAR(255)
-- ----------------------------------------------------------------------------

-- ----------------------------------------------------------------------------
-- Connect sesam2000 Database
-- ----------------------------------------------------------------------------

-- ########## DROP TABLES ########################

-- ----------------------------------------------------------------------------
-- Tables without active & passive references
-- ----------------------------------------------------------------------------

drop table accounts;
drop table cal_sheets;
drop table defaults;
drop table sessions;

-- ----------------------------------------------------------------------------
-- Tables with only active references ( they refer to another table )
-- ----------------------------------------------------------------------------

drop table terms;
drop table capacities;
drop table drive_vendors;
drop table syntaxes;   			
drop table loader_contents;
drop table restore_users;
drop table result_lbls;                 
drop table task_group_relations;        
drop table servers;
drop table user_scheds;

-- ----------------------------------------------------------------------------
-- Tables with active and passive references
-- the sequence of drops MUST be kept due to inner relations
-- ----------------------------------------------------------------------------

drop table task_events;
drop table newday_events;
drop table mediapools_events;
drop table restore_events;
drop table command_events;
drop table tasks;
drop table media;
drop table media_pools;
drop table restore_tasks;
drop table results;
drop table task_sources;        
drop table hw_drives;
drop table hw_loaders;
drop table interfaces;
drop table clients;
drop table locations;

-- ----------------------------------------------------------------------------
-- Tables with only passive references ( they are referred from other tables )
-- ----------------------------------------------------------------------------

drop table schedules;
drop table drive_types;
drop table media_types;
drop table oper_systems;
drop table drive_groups;
drop table restore_results;
drop table task_groups;
drop table task_types;
drop table params_fix;


-- ########## CREATE TABLES ########################

-- ----------------------------------------------------------------------------
-- Tables with only passive references ( they are referred from other tables )
-- ----------------------------------------------------------------------------


CREATE TABLE drive_types (
	drive_typ       VARCHAR(15) NOT NULL PRIMARY KEY,
	generic_typ     VARCHAR(10) NOT NULL 
);

CREATE TABLE media_types (
	media_typ       VARCHAR(20) NOT NULL PRIMARY KEY
);

CREATE TABLE oper_systems (
        os              VARCHAR(20) NOT NULL PRIMARY KEY,
        platform        VARCHAR(20) NOT NULL
); 

CREATE TABLE drive_groups (
	grp_id          INTEGER NOT NULL PRIMARY KEY,
	grp_name        VARCHAR(50),
	sms_flag        VARCHAR(1),
        restore_drive   INTEGER,
	text            VARCHAR(100)
);

CREATE TABLE restore_results (
        restore_id      VARCHAR(21) NOT NULL PRIMARY KEY,
        start_tim       VARCHAR(21) NOT NULL,
	r_task		VARCHAR(49) NOT NULL,
        saveset         VARCHAR(32) NOT NULL,
        task            VARCHAR(32) NOT NULL,
        datum           VARCHAR(21) NOT NULL,
        cnt             INTEGER NOT NULL,
        rest_typ        VARCHAR(2) NOT NULL,
        genmode         VARCHAR(2),
        listmode        VARCHAR(32),
        tree_typ        VARCHAR(2) NOT NULL,
        mode            VARCHAR(2) NOT NULL,
        recover         VARCHAR(64),
        onlinemode      VARCHAR(64),
        client_id       INTEGER NOT NULL,
        client          VARCHAR(64) NOT NULL,
        target          VARCHAR(255) NOT NULL,
        user_name       VARCHAR(255) NOT NULL,
	subtask_flag	CHAR(1),
	parent_task	CHAR(49),
        location        VARCHAR(50),
        drive_num       INTEGER,
        i_name          VARCHAR(64),
        filter          VARCHAR(255),
        reloc_source    VARCHAR(255),
        state           VARCHAR(1) NOT NULL,
        stop_tim        VARCHAR(21),
        size            VARCHAR(32),
        options         VARCHAR(64),
        msg             VARCHAR(128),
	saveset_exist   VARCHAR(1)
);

CREATE TABLE task_groups (
        grp_name        VARCHAR(50) NOT NULL PRIMARY KEY,
        text            VARCHAR(100),
        results_sts     VARCHAR(1),
        prepost         VARCHAR(16),
        prepost_switch  VARCHAR(1)	
);

CREATE TABLE task_types (
        backup_type     VARCHAR(32) NOT NULL PRIMARY KEY,
        backup_cmd      VARCHAR(20),
        backup_options  VARCHAR(64),
        prepost         VARCHAR(16),
        prepost_cmd     VARCHAR(20),
        restore_cmd     VARCHAR(20),
        restore_options VARCHAR(64),
        r_prepost       VARCHAR(16),
        r_prepost_cmd   VARCHAR(20),
        source_prefix   VARCHAR(20),
        platform        VARCHAR(20),
        flags           VARCHAR(32),
        protection      VARCHAR(1),
        komment         VARCHAR(40)
);

CREATE TABLE params_fix (
	kunde           VARCHAR(50) NOT NULL PRIMARY KEY,
	rest_eol        INTEGER NOT NULL,
	min_free        INTEGER NOT NULL,
        typ             VARCHAR(20) NOT NULL,
        version         VARCHAR(32) NOT NULL,
        inst_date       VARCHAR(21) NOT NULL,
        inst_cryp       VARCHAR(21),
        update_date     VARCHAR(21) NOT NULL,
        val1            VARCHAR(128),
        val2            VARCHAR(128),
        val3            VARCHAR(128),
        val4            VARCHAR(128),
	sts             VARCHAR(255),
	msg             VARCHAR(255)
);


-- ----------------------------------------------------------------------------
-- Tables with active and passive references
-- the sequence of CREATE MUST be kept due to inner relations
-- ----------------------------------------------------------------------------

CREATE TABLE schedules (
	name            VARCHAR(30) NOT NULL PRIMARY KEY,
	cyc_flag        VARCHAR(1) NOT NULL,
	abs_flag        VARCHAR(1) NOT NULL,
	p_count         INTEGER,
	p_base          VARCHAR(3),
	mo              VARCHAR(1),
	tu              VARCHAR(1),
	we              VARCHAR(1),
	th              VARCHAR(1),
	fr              VARCHAR(1),
	sa              VARCHAR(1),
	su              VARCHAR(1),
	day_of_mth      VARCHAR(2),
	mth_of_yea      VARCHAR(2),
	wk_of_mth       VARCHAR(2),
	day_of_wk       VARCHAR(10),
	start_date      VARCHAR(21),
	end_date        VARCHAR(21),
	exec            VARCHAR(1),
	start_time      VARCHAR(5),
	duration        VARCHAR(5),
	day_offset      INTEGER,
        sepcomment      VARCHAR(64),
        komment         VARCHAR(64)
);

CREATE TABLE task_sources (
        task   	        VARCHAR(32)  NOT NULL,
        version_id      INTEGER      NOT NULL,
        source          VARCHAR(255) NOT NULL,
        timestamp       VARCHAR(21),
        user_name       VARCHAR(255),
        PRIMARY KEY (task,version_id)
);

CREATE TABLE results (
	saveset          VARCHAR(32) NOT NULL PRIMARY KEY,
        task             VARCHAR(32) NOT NULL,
	datum            VARCHAR(21) NOT NULL,
        cnt              INTEGER NOT NULL ,
	fdi_typ          VARCHAR(2),
	lbl_cnt          INTEGER,
	drive_num        INTEGER,
	client_id        INTEGER,
	client           VARCHAR(64),
	location         VARCHAR(50),
	source           VARCHAR(254),
        version_id       INTEGER,
	exclude          VARCHAR(254),
	start_tim        VARCHAR(21),
	stop_tim         VARCHAR(21),
        session_id       VARCHAR(32),
	state            VARCHAR(1),
	blocks           INTEGER,
	msg              VARCHAR(100),
        sms_flag         VARCHAR(1),
        i_name           VARCHAR(64),
	sbc_start        VARCHAR(21),
	saveset_exist    VARCHAR(2),
        media_pool       VARCHAR(16),
        backup_cmd       VARCHAR(20),
        backup_type      VARCHAR(32),
        restore_options  VARCHAR(64),
        compress_flag    VARCHAR(1),
        crypt_flag       VARCHAR(1),
        crypt_key        VARCHAR(128),
	original_saveset VARCHAR(64)
);

CREATE TABLE restore_tasks (
	r_task		VARCHAR(49) NOT NULL PRIMARY KEY,
        saveset         VARCHAR(32) NOT NULL,
        task            VARCHAR(32) NOT NULL,
        datum           VARCHAR(21) NOT NULL,
        cnt             INTEGER NOT NULL,
        rest_typ        VARCHAR(2) NOT NULL,
        genmode         VARCHAR(2),
        listmode        VARCHAR(32),
        tree_typ        VARCHAR(2) NOT NULL,
        mode            VARCHAR(2) NOT NULL,
        recover         VARCHAR(64),
        onlinemode      VARCHAR(64),
        client_id       INTEGER NOT NULL,
        client          VARCHAR(64) NOT NULL,
        target          VARCHAR(255) NOT NULL,
        user_name       VARCHAR(255) NOT NULL,
	subtask_flag	VARCHAR(1),
	parent_task	VARCHAR(49),
        location        VARCHAR(50),
        drive_num       INTEGER,
        i_name          VARCHAR(64),
        filter          VARCHAR(255),
        reloc_source    VARCHAR(255),
        r_prepost       VARCHAR(16),
	make_stamp	VARCHAR(21) NOT NULL,
        eol             INTEGER,
        restore_cmd     VARCHAR(64),
        options         VARCHAR(64),
	komment		VARCHAR(100)
);

CREATE TABLE locations (
        id              INTEGER NOT NULL PRIMARY KEY,
	name            VARCHAR(50),
	parent          INTEGER references locations (id),
	describe        VARCHAR(128),
	contact         VARCHAR(128),
	komment         VARCHAR(128)
);

CREATE TABLE clients (
	client_id       INTEGER NOT NULL PRIMARY KEY,
        name            VARCHAR(64) NOT NULL,
	location        INTEGER references locations (id),
	os              VARCHAR(20) NOT NULL references oper_systems (os),
	net_prot        VARCHAR(10) NOT NULL ,
	accessmode      VARCHAR(10),
	komment         VARCHAR(255),
   	permit          VARCHAR(1),
        user_name       VARCHAR(255),
        password        VARCHAR(255),
	access_options  VARCHAR(255),
	stpd_options    VARCHAR(32),
	stpd_port       VARCHAR(32),
        sbc_version     VARCHAR(20),
        data_mover      VARCHAR(64)
);

CREATE TABLE hw_loaders (
	loader_num      INTEGER NOT NULL PRIMARY KEY,
	device          VARCHAR(254) NOT NULL,
	client_id       INTEGER NOT NULL references clients (client_id),
	typ             VARCHAR(32) NOT NULL,
	ctrl            VARCHAR(10) NOT NULL,
	slots           INTEGER NOT NULL,
        drives          INTEGER,
        ports           INTEGER,
        transport       INTEGER,
        first_slot      INTEGER,
        last_slot       INTEGER,
        autounload      VARCHAR(1),
        barcode         VARCHAR(1)
);

CREATE TABLE hw_drives (
	drive_num       INTEGER NOT NULL PRIMARY KEY,
	device          VARCHAR(254) NOT NULL ,
	client_id       INTEGER NOT NULL references clients (client_id),
	typ             VARCHAR(15) NOT NULL references drive_types (drive_typ),
        name            VARCHAR(32),
	loader_num      INTEGER references hw_loaders (loader_num),
	kompress        VARCHAR(1),
	sts             VARCHAR(132),
	msg             VARCHAR(132),
	occupy          VARCHAR(20),
	done            INTEGER,
	run             INTEGER,
	waiting         INTEGER,
        grp_id          INTEGER references drive_groups (grp_id),
        sms_cnts        INTEGER,
       	label           VARCHAR(30),
        timeout         INTEGER,
        clean_bit       VARCHAR(1),
        loader_drive    INTEGER,
        path            VARCHAR(132),
        block_size      INTEGER,
        sms_nr          INTEGER,
        segment_size    INTEGER
);


CREATE TABLE media_pools (
        name            VARCHAR(16) NOT NULL PRIMARY KEY,
        pool_id         INTEGER NOT NULL,
        descript        VARCHAR(80),
        drive_grp       INTEGER NOT NULL references drive_groups (grp_id),
        media_strg      VARCHAR(64) NOT NULL,
        media_chg       VARCHAR(8) NOT NULL,
        disk_capac      VARCHAR(16),
        disk_dir        VARCHAR(254),
        eol             INTEGER,
        accept_empty    VARCHAR(2),
        accept_eol      VARCHAR(2),
        accept_spare    VARCHAR(2)
);

CREATE TABLE interfaces (
	client_id       INTEGER  NOT NULL references clients (client_id),
        i_name          VARCHAR(64) NOT NULL UNIQUE,
        PRIMARY KEY (client_id,i_name)
);


-- task_events.object references tasks.task or task_groups.grp_name

CREATE TABLE task_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          VARCHAR(50) NOT NULL,
        schedule        VARCHAR(30) NOT NULL references schedules (name),
        grp_flag        VARCHAR(1) NOT NULL,
        priority        INTEGER NOT NULL,
        suppress        VARCHAR(1),
        owner           VARCHAR(30) NOT NULL,
        fdi_typ         VARCHAR(2) NOT NULL,
        media_pool      VARCHAR(16) NOT NULL,
        drive_num       INTEGER references hw_drives (drive_num),
	i_name		VARCHAR(64) references interfaces (i_name),
        data_mover      VARCHAR(64)
);

CREATE TABLE newday_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          VARCHAR(16) NOT NULL references params_fix (kunde),
        schedule        VARCHAR(30) NOT NULL references schedules (name),
        priority        INTEGER NOT NULL,
        suppress        VARCHAR(1),
        owner           VARCHAR(30) NOT NULL
);

CREATE TABLE mediapools_events (
        id              INTEGER NOT NULL PRIMARY KEY,
        object          VARCHAR(16) NOT NULL references media_pools (name),
        drive           VARCHAR(16),
        schedule        VARCHAR(30) NOT NULL references schedules (name),
        priority        INTEGER NOT NULL,
        suppress        VARCHAR(1),
        owner           VARCHAR(30) NOT NULL,
        grp_flag        VARCHAR(1) NOT NULL,
        m_count         INTEGER,
        label           VARCHAR(30),
        emergency       VARCHAR(30)
);

CREATE TABLE restore_events (
        id               INTEGER NOT NULL PRIMARY KEY,
	object           VARCHAR(49) NOT NULL references restore_tasks (r_task),
        schedule         VARCHAR(30) NOT NULL references schedules (name),
        priority         INTEGER NOT NULL,
        suppress         VARCHAR(1),
        owner            VARCHAR(30) NOT NULL,
        drive_num        INTEGER,
        i_name           VARCHAR(64),
        listmode         VARCHAR(32),
        absolute_flag    VARCHAR(1),
        saveset_start    INTEGER,
        saveset_end      INTEGER,
        min_max          VARCHAR(21),
        date_start       VARCHAR(21),
        date_end         VARCHAR(21),
        state            VARCHAR(12),
        cfdi_type        VARCHAR(12),
        media_pools      VARCHAR(255),
        media_tolerance  VARCHAR(21),
        media_preference VARCHAR(21),
        data_mover       VARCHAR(64),
        use_saveset      VARCHAR(32),
        restore_cmd      VARCHAR(64),
        options          VARCHAR(64)

);

CREATE TABLE command_events (
        id               INTEGER NOT NULL PRIMARY KEY,
        object           VARCHAR(50) NOT NULL,
        schedule         VARCHAR(30) NOT NULL references schedules (name),
        priority         INTEGER NOT NULL,
        suppress         VARCHAR(1),
        owner            VARCHAR(30) NOT NULL,
        type             VARCHAR(1) NOT NULL,
        host             VARCHAR(64) NOT NULL,
        user_name        VARCHAR(32) NOT NULL,
        command          VARCHAR(255) NOT NULL
);

CREATE TABLE media (
    	label           VARCHAR(30) NOT NULL PRIMARY KEY,
    	barcode         VARCHAR(30) ,
        pool            VARCHAR(16) NOT NULL references media_pools (name),
        id              INTEGER NOT NULL ,
	sperrkz         VARCHAR(1) NOT NULL ,
	sichtag         VARCHAR(21) NOT NULL ,
	eol             VARCHAR(21),
	drive_num       INTEGER references hw_drives (drive_num),
        init_drive      INTEGER,
	folgekass       INTEGER,
	kasstyp         VARCHAR(20) NOT NULL references media_types (media_typ),
	lader           INTEGER references hw_loaders (loader_num),
	slot            INTEGER,
	gefuellt        INTEGER,
	eom_state       VARCHAR(1),
	first_init      VARCHAR(21),
        close_tape      VARCHAR(1),
	init_flag       VARCHAR(1),
	error           INTEGER,
	error_delt      INTEGER,
	use_count       INTEGER,
	duplflag        VARCHAR(1),
	kommentar       VARCHAR(80)
);

CREATE TABLE tasks (
	task   	        VARCHAR(32) NOT NULL PRIMARY KEY,
        backup_type     VARCHAR(32) references task_types (backup_type),
	client_id       INTEGER NOT NULL references clients (client_id),
	source          VARCHAR(254),
	exclude         VARCHAR(150),
	komment         VARCHAR(40),		
	results_sts     VARCHAR(1),
        backup_cmd      VARCHAR(64),
	backup_options  VARCHAR(64),
	restore_options VARCHAR(64),
	prepost         VARCHAR(16),
        r_prepost       VARCHAR(16),
        nfs_mount       VARCHAR(1),
        filesystem      VARCHAR(1),
        compress_flag   VARCHAR(1),
        crypt_flag      VARCHAR(1),
        crypt_key       VARCHAR(128)
);

-- ----------------------------------------------------------------------------
-- Tables with only active references ( they refer to another table )
-- ----------------------------------------------------------------------------

CREATE TABLE terms (
       id               INTEGER NOT NULL PRIMARY KEY,
       type             VARCHAR(1) NOT NULL,
       schedule         VARCHAR(30) NOT NULL references schedules (name),
       next_exec        VARCHAR(21),
       next_end         VARCHAR(21)
);

CREATE TABLE capacities (
	drive_typ       VARCHAR(15) NOT NULL references drive_types (drive_typ),
	media_typ       VARCHAR(20) NOT NULL references media_types (media_typ),
	kapaz_num       INTEGER NOT NULL,
        protection      VARCHAR(1) NOT NULL,
        PRIMARY KEY (drive_typ,media_typ)
);

CREATE TABLE drive_vendors (
	drive_typ       VARCHAR(15) NOT NULL references drive_types (drive_typ),
	vendor_typ      VARCHAR(16) NOT NULL,
        protection      VARCHAR(1) NOT NULL,
	PRIMARY KEY (drive_typ,vendor_typ)
);

CREATE TABLE syntaxes (
	os              VARCHAR(20) NOT NULL references oper_systems (os),
	command         VARCHAR(20) NOT NULL,
	syntax          VARCHAR(50) NOT NULL,
        PRIMARY KEY (os,command)
);

CREATE TABLE task_group_relations (
        grp_name        VARCHAR(50) NOT NULL references task_groups (grp_name),
	task   	        VARCHAR(32) NOT NULL references tasks (task),
	task_order      INTEGER,
        PRIMARY KEY (grp_name,task)
);

CREATE TABLE result_lbls (
        saveset         VARCHAR(32) NOT NULL references results (saveset),
	num             INTEGER NOT NULL,
	label           VARCHAR(30) NOT NULL,
        segment         VARCHAR(20) NOT NULL,
        PRIMARY KEY (saveset,num)
);

CREATE TABLE restore_users (
	name            VARCHAR(255) NOT NULL,
	task            VARCHAR(32) NOT NULL references tasks (task),
	path            VARCHAR(132) NOT NULL,
	komment         VARCHAR(100),
        PRIMARY KEY (name,task,path)
);

CREATE TABLE loader_contents (
        loader          INTEGER	NOT NULL references hw_loaders (loader_num),
        object          VARCHAR(10) NOT NULL,
        number          INTEGER	NOT NULL,
        lbl             VARCHAR(30),
	barcode         VARCHAR(30),
        check_lbl       VARCHAR(1),
        checkedlbl      VARCHAR(30),
        from_object     VARCHAR(10),
        from_number     INTEGER,
        to_object       VARCHAR(10),
        to_number       INTEGER,	
        PRIMARY KEY (loader,object,number)
);

CREATE TABLE servers (
        name            VARCHAR(64) NOT NULL PRIMARY KEY,
	os              VARCHAR(20) NOT NULL references oper_systems (os),
        ip_address      VARCHAR(64),
        rmi_port        INTEGER,
        ctrl_port       INTEGER,
        db_port         INTEGER,
        db_name         VARCHAR(73),
        db_alias        VARCHAR(73),
        db_type         VARCHAR(32),
        connect         VARCHAR(1),
        komment         VARCHAR(80)
);

CREATE TABLE user_scheds (
     name            VARCHAR(30) NOT NULL references schedules (name),
     date_name       VARCHAR(32) NOT NULL,
     date_pattern    VARCHAR(32) NOT NULL,
     next_exec       VARCHAR(32),
     notices         VARCHAR(100),
     PRIMARY KEY (name,date_name)
);

-- ----------------------------------------------------------------------------
-- Tables without active & passive references
-- ----------------------------------------------------------------------------

CREATE TABLE accounts (
        account_name       VARCHAR(64) NOT NULL PRIMARY KEY,
        kunde              VARCHAR(64),
        smtp_email_address VARCHAR(64) NOT NULL,
        smtp_server        VARCHAR(64) NOT NULL,
        mail_username      VARCHAR(64),
        mail_password      VARCHAR(64),
        mail_to            VARCHAR(128) NOT NULL,
        mail_cc            VARCHAR(128),
        mail_bcc           VARCHAR(128),
        service_location   VARCHAR(64)
);

CREATE TABLE cal_sheets (
	id		VARCHAR(30) PRIMARY KEY,
	start		VARCHAR(21),
	end_time        VARCHAR(21),
	ev_type		VARCHAR(3),
	ev_id		INTEGER,
	schedule	VARCHAR(30),
        priority        INTEGER,
	state		VARCHAR(3),
        object          VARCHAR(132),
        suppress        VARCHAR(1),
	msg		VARCHAR(132)
);

CREATE TABLE defaults (	
        key             VARCHAR(32) NOT NULL,
        user_name       VARCHAR(255) NOT NULL ,
        value           VARCHAR(255) NOT NULL,
        PRIMARY KEY     (key,user_name)
);

insert into defaults values('database version','sesam','$Id: sesam_db_pg.sql,v 1.42 2007/03/03 08:09:20 sesam Exp $' );

CREATE TABLE sessions (
	session_id      VARCHAR(32) PRIMARY KEY,
	object		VARCHAR(32),
	komment		VARCHAR(80)
);


CREATE TABLE preferences (
        pref_node       VARCHAR(255)  NOT NULL,
        pref_user       VARCHAR(255)  NOT NULL,
        pref_key        VARCHAR(255)  NOT NULL,
        pref_value      VARCHAR(255)  NOT NULL,
        PRIMARY KEY     (pref_node,pref_user,pref_key)
)

